@@ -36,6 +36,9 @@ def convert_layer(current_layer: Layer, target_data_format: str, input_shape: Li
         layer_type = type(current_layer)
         handlers = layer_to_config_handlers.get(layer_type, [])
         layer_config_handlers.extend(handlers)
+        if hasattr(current_layer, 'get_special_data_format_handler'):
+            special_data_format_handler = current_layer.get_special_data_format_handler()
+            layer_config_handlers.append(special_data_format_handler)
 
     for layer_config_handler in layer_config_handlers:
         logger.debug(f"using config handler, handler name: {layer_config_handler.__name__}")
