@@ -1,5 +1,5 @@
 import logging
-from typing import List, Dict, Set, Union, Optional
+from typing import List, Dict, Set, Union, Optional, Tuple
 
 import tensorflow as tf
 from keras.engine.keras_tensor import KerasTensor
@@ -74,6 +74,32 @@ class ModelConverter:
                 return axis - 1
         return axis
 
+    @staticmethod
+    def _default_call_tf_op_lambda_layer(
+            converted_layer: TFOpLambda, call_args: Tuple, call_kwargs: Dict,
+            node_input_tensors:  Union[KerasTensor, List[KerasTensor]]) -> KerasTensor:
+        new_tfoplambda_args = list(call_args)
+        if not isinstance(node_input_tensors, list):
+            node_input_tensors = [node_input_tensors]
+        for i, arg in enumerate(call_args):
+            if isinstance(arg, KerasTensor):
+                try:
+                    tensor_index = [tensor.name for tensor in node_input_tensors].index(arg.name)
+                    new_tfoplambda_args[i] = node_input_tensors.pop(tensor_index)
+                except (IndexError, ValueError):
+                    pass
+
+        new_tfoplambda_kwargs = call_kwargs.copy()
+        for key, arg in call_kwargs.items():
+            if isinstance(arg, KerasTensor):
+                try:
+                    tensor_index = [tensor.name for tensor in node_input_tensors].index(arg.name)
+                    new_tfoplambda_kwargs[key] = node_input_tensors.pop(tensor_index)
+                except (IndexError, ValueError):
+                    pass
+
+        return converted_layer(*new_tfoplambda_args, **new_tfoplambda_kwargs)
+
     def _call_tf_op_lambda_layer(
             self, converted_layer: TFOpLambda, node_input_tensors: Union[KerasTensor, List[KerasTensor]],
             current_layer: TFOpLambda, transform_signal: bool) -> KerasTensor:
@@ -111,7 +137,7 @@ class ModelConverter:
                 transformed_axis = self._convert_axis_channel(call_args[1:][0], last_input_axis_index)
                 call_args = (call_args[0], transformed_axis)
 
-        return converted_layer(node_input_tensors, *call_args[1:], **call_kwargs)
+        return self._default_call_tf_op_lambda_layer(converted_layer, call_args, call_kwargs, node_input_tensors)
 
     def _convert_tensor(self, tensor: tf.Tensor) -> tf.Tensor:
         tensor_id = id(tensor)
